@@ -7,4 +7,4 @@ class Widget(models.Model):
     category = models.ForeignKey(Category, null=True, blank=True)
     title = models.CharField(max_length=100)
     description = models.CharField(max_length=200, null=True, blank=True)
-    active = models.BooleanField()
+    active = models.BooleanField(default=True)
